---
title: Data Binding
page_title: Data Binding - DropDownTree - Kendo UI for Vue
description: "Bind the Kendo UI DropDownTree wrapper for Vue to local data arrays or remote data services."
slug: databinding_dropdowntree
position: 1
---

# Data Bindingng

The DropDownTree provides support for binding it to [local data arrays](#toc-binding-to-local-data-arrays) and to [remote data services](#toc-binding-to-remote-data-services).

## Binding to Local Data Arrays

The DropDownTree enables you to bind it to:
* [Simple local data](#toc-simple-local-data-binding)
* [Complex local data](#toc-complex-local-data-binding)

### Simple Local Data Binding

The following example demonstrates how to create and bind the DropDownTree to a simple local data source.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-dropdowntree :data-source="localDataSource" :placeholder="'Select ...'" style="width: 300px;"></kendo-dropdowntree>
</div>
```
```js
Vue.use(DropDownTreeInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            localDataSource: new kendo.data.HierarchicalDataSource({
                data: [{
                    text: 'Furniture',
                    items: [
                        { text: 'Tables & Chairs' },
                        { text: 'Sofas' },
                        { text: 'Occasional Furniture' }
                    ]
                },{
                    text: 'Decor',
                    items: [
                        { text: 'Bed Linen' },
                        { text: 'Curtains & Blinds' },
                        { text: 'Carpets' }
                    ]
                }]
            })
        }
    }
})
```

### Complex Local Data Binding

The following example demonstrates how to create and bind the DropDownTree to a complex local data source.

```html
<div id="vueapp" class="vue-app">
    <kendo-dropdowntree :data-source="complexLocalDataSource"
                        :data-text-field="['categoryName', 'subCategoryName']"
                        :placeholder="'Select ...'"
                        style="width: 300px;">
    </kendo-dropdowntree>
</div>
```
```js
Vue.use(DropDownTreeInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            complexLocalDataSource: new kendo.data.HierarchicalDataSource({
                data: [{
                    categoryName: 'Storage',
                    subCategories: [
                        { subCategoryName: 'Wall Shelving' },
                        { subCategoryName: 'Floor Shelving' },
                        { subCategoryName: 'Kids Storage' }
                    ]
                },{
                    categoryName: 'Lights',
                    subCategories: [
                        { subCategoryName: 'Ceiling' },
                        { subCategoryName: 'Table' },
                        { subCategoryName: 'Floor' }
                    ]
                }],
                schema: {
                    model: {
                    children: 'subCategories'
                    }
                }
            })
        }
    }
})
```

## Binding to Remote Data Services

You can bind the DropDownTree to a remote dataset by:
* [Defining an inner HierarchicalDataSource for the DropDownTree](#toc-defining-inner-hierarchicaldatasource)
* [Using an external HierarchicalDataSource component](#toc-using-the-hierarchicaldatasource-component)
* [Using the `data` method](#toc-using-the-data-method)

### Defining Inner HierarchicalDataSource

The following example demonstrates how to define an inner [HierarchicalDataSource component]({% slug overview_hierarchicaldatasource %}) for the DropDownTree.

```html
<div id="vueapp" class="vue-app">
    <kendo-dropdowntree data-text-field="FullName" data-value-field="EmployeeId">
        <kendo-hierarchicaldatasource slot="kendo-hierarchicaldatasource"
                                      transport-read-url="https://demos.telerik.com/kendo-ui/service/Employees"
                                      transport-read-data-type="jsonp"
                                      schema-model-id="EmployeeId"
                                      schema-model-has-children="HasEmployees"
                                      :placeholder="'Select ...'"
                                      style="width: 300px;">
        </kendo-hierarchicaldatasource>
    </kendo-dropdowntree>
</div>
```
```js

Vue.use(DropDownTreeInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp"
})
```

### Using the HierarchicalDataSource Component

The following example demonstrates how to bind the DropDownTree to an external [HierarchicalDataSource component]({% slug overview_hierarchicaldatasource %}).

```html
<div id="vueapp" class="vue-app">
    <kendo-hierarchicaldatasource ref="remoteDataSourceComponent"
                                  transport-read-url="https://demos.telerik.com/kendo-ui/service/Employees"
                                  transport-read-data-type="jsonp"
                                  schema-model-id="EmployeeId"
                                  schema-model-has-children="HasEmployees"
                                  :placeholder="'Select ...'"
                                  style="width: 300px;">
    </kendo-hierarchicaldatasource>
    <kendo-dropdowntree data-source-ref="remoteDataSourceComponent" data-text-field="FullName">
    </kendo-dropdowntree>
</div>
```
```js

Vue.use(DropDownTreeInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp"
})
```

### Using the data Method

The following example demonstrates how to bind the DropDownTree to remote DataSource that is initialized in the `data` method.

```html
<div id="vueapp" class="vue-app">
    <kendo-dropdowntree expand-mode="single"
                        :data-source="remoteDataSource"
                        data-text-field="FullName"
                        :placeholder="'Select ...'"
                        style="width: 300px;">
    </kendo-dropdowntree>
</div>
```
```js

Vue.use(DropDownTreeInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            remoteDataSource: new kendo.data.HierarchicalDataSource({
                transport: {
                    read: {
                        url: 'https://demos.telerik.com/kendo-ui/service/Employees',
                        dataType: 'jsonp'
                    }
                },
                schema: {
                    model: {
                        id: 'EmployeeId',
                        hasChildren: 'HasEmployees'
                    }
                }
            })
        }
    }
})
```

## Suggested Links

* [Kendo UI HierarchicalDataSource for Vue]({% slug overview_hierarchicaldatasource %})
* [Kendo UI DataSource for jQuery](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource)
* [Kendo UI DropDownTree for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/dropdowntree/overview)
* [API Reference of the DropDownTree Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdowntree)
